import numpy as np
import scipy.optimize

def gaussian(height, center_x, center_y, width_x, width_y):
# Returns a gaussian function with the given parameters.
    width_x = float(width_x)
    width_y = float(width_y)
    return lambda x,y: height*np.exp(
                -0.5*(((center_x-x)/width_x)**2+((center_y-y)/width_y)**2))

def moments(data):
#   Returns (height, x, y, width_x, width_y)
#   the gaussian parameters of a 2D distribution by calculating its moments.
#   It is used by the fitting procedure to extimate initial values
    total = data.sum()
    X, Y = np.indices(data.shape)
    x = (X*data).sum()/total
    y = (Y*data).sum()/total
    col = data[:, int(y)]
    width_x = np.sqrt(np.abs((np.arange(col.size)-y)**2*col).sum()/col.sum())
    row = data[int(x), :]
    width_y = np.sqrt(np.abs((np.arange(row.size)-x)**2*row).sum()/row.sum())
    height = data.max()
    return height, x, y, width_x, width_y

def fitgaussian(data):
#   Returns (height, x, y, width_x, width_y)
#   the gaussian parameters of a 2D distribution found by a fit
    params = moments(data)
    errorfunction = lambda x: np.ravel(gaussian(*x)(*np.indices(data.shape)) - data)
    p, success = scipy.optimize.leastsq(errorfunction, params)
    return np.array([p[0], p[2], p[1], p[4], p[3]])

