from __future__ import print_function
import sys, os, requests, json

URL='http://cas.sdss.org/public/en/tools/search/x_results.aspx'
FMT='json'
outdir='.'

QRY = """SELECT TOP 10
   p.objid,p.ra,p.dec,p.u,p.g,p.r,p.i,p.z,
   p.run, p.rerun, p.camcol, p.field,
   s.specobjid, s.class, s.z as redshift,
   s.plate, s.mjd, s.fiberid
FROM PhotoObj AS p
   JOIN SpecObj AS s ON s.bestobjid = p.objid
WHERE 
   p.u BETWEEN %f AND %f
   AND g BETWEEN %f AND %f"""

def get_list(ra_center, dec_center, size_arcmin):
    size_deg = size_arcmin/120.
    ra_min = ra_center-size_deg
    ra_max = ra_center+size_deg
    dec_min = dec_center-size_deg
    dec_max = dec_center+size_deg
    qry = QRY % (ra_min, ra_max, dec_min, dec_max)
    params = {'cmd': qry, 'format': FMT, 'searchtool': 'SQL'}
    response = requests.get(URL, params=params)
    if not response.ok:
        raise Exception("Error retrieving data: " + response.reason)
    return json.loads(response.text)

if __name__ == '__main__':
    if len(sys.argv)!=4 :
        print("RA,DEC, size, must be given!")
        sys.exit(-1)
    ra_center = float(sys.argv[1])
    dec_center = float(sys.argv[2])
    size = float(sys.argv[3])
    found = get_list(ra_center, dec_center, size)

