from __future__ import print_function

import numpy as np
import matplotlib.cm as cm
import matplotlib.pyplot as plt

#################  Dati di ingresso
DELTAX=0.1   # Risoluzione spaziale
SYMX=51-1    # Posizione centro X
SYMY=51-1    # Posizione centro Y
filename='wind_2d.stat'
###################################

data = np.loadtxt(filename, skiprows=3, unpack=True)  # Lettura dati

ipoints = long(np.max(data[0])-np.min(data[0])+1)  # Dimensione X
jpoints = long(np.max(data[1])-np.min(data[1])+1)  # Dimensione Y

ZS = data[4].reshape(ipoints, -1).transpose()    # Trasforma in mappa
WM = data[5].reshape(ipoints, -1).transpose()    # Trasforma in mappa
WUT = data[7].reshape(ipoints, -1).transpose()   # Trasforma in mappa
WVT = data[8].reshape(ipoints, -1).transpose()   # Trasforma in mappa

arrayI = np.arange(0, ipoints)*DELTAX   # Scale spaziali
arrayJ = np.arange(0, jpoints)*DELTAX
maxI = np.max(arrayI)
maxJ = np.max(arrayJ)

im = plt.imshow(WM, interpolation='bilinear', origin='lower',  # Immagine
                extent=[0, maxI, 0, maxJ], cmap=cm.hot_r)

cbar = plt.colorbar(im, orientation='vertical')  # Barra con scala colori
cbar.set_label("Wind speed (m/s)")

maxzs = np.max(ZS)
minzs = np.min(ZS)
levels = np.linspace(minzs, maxzs, 25)            # Livelli per contorni

plt.contour(arrayI, arrayJ, ZS, levels, colors='k', origin='lower', linewidths=0.5)

plt.plot([arrayI[SYMX]],[arrayJ[SYMY]], "o", color='black', ms=8)  # Punto centrale

plt.quiver(arrayI[::5], arrayJ[::5], WUT[::5,::5], WVT[::5,::5],   # Frecce
           headwidth=6, headlength=6)

plt.title("Wind speed - hour 007 or hour 000 MST")
plt.xlabel('Km')
plt.ylabel('Km')
plt.tight_layout()
plt.show()
plotfile = 'wind_speed.png'
plt.savefig(plotfile, dpi=200)
print("Creato file con plot:", plotfile)
